.. _about_author:

About the Author
------------------------------------------------------------------------------

Sean Kruzel 
 - https://github.com/closedLoop
 - https://www.linkedin.com/in/skruzel/
 - https://twitter.com/seankruzel


Special thanks for the initial project layout based on work from https://github.com/MacHu-GWU

